---
title: __float22half2_rn
description: "| 产品 | 是否支持 |"
url: https://www.hiascend.com/document/detail/zh/canncommercial/latest/API/ascendcopapi/atlasascendc_api_07_10796.html
sourcePath: /source/zh/canncommercial/900/API/ascendcopapi/atlasascendc_api_07_10796.html
indexId: 7fd38762154f2be490a5f78d18af5e0932f842c07fc43ab79a1a534e56fb69be77
---
# __float22half2_rn

#### 产品支持情况

| 产品 | 是否支持 |
| --- | --- |
| Atlas 350 加速卡 | √ |
| Atlas A3 训练系列产品 / Atlas A3 推理系列产品 | x |
| Atlas A2 训练系列产品 / Atlas A2 推理系列产品 | x |
| Atlas 200I/500 A2 推理产品 | x |
| Atlas 推理系列产品 AI Core | x |
| Atlas 推理系列产品 Vector Core | x |
| Atlas 训练系列产品 | x |


#### 功能说明

将float2类型数据遵循CAST_RINT模式转换为half2类型，返回转换后的half2类型数据。


#### 函数原型

```
inline half2 __float22half2_rn(const float2 x)
```


#### 参数说明


**表1 参数说明**

| 参数名 | 输入/输出 | 描述 |
| --- | --- | --- |
| x | 输入 | 源操作数。 |


#### 返回值说明

将输入的两个分量遵循CAST_RINT模式转换成的half2类型数据。


#### 约束说明

SIMT编程场景当前不支持使用该接口。


#### 需要包含的头文件

使用该接口需要包含"simt_api/asc_fp16.h"头文件。

```
#include "simt_api/asc_fp16.h"
```


#### 调用示例

SIMD与SIMT混合编程场景：```
// 使用小向量可提升数据搬运效率
__simt_vf__ __launch_bounds__(1024) inline void simt_float22half2_rn(__gm__ float2* input, __gm__ half2* output, uint32_t input_total_length)
{
    uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
    // 每个线程处理1个float2类型的数据，即2个float类型的数据，因此idx >= input_total_length / 2的线程不处理数据
    if (idx >= input_total_length / 2) {
        return;
    } 
    output[idx] = __float22half2_rn(input[idx]);
}

__global__ __vector__ void cast_kernel(__gm__ float* input, __gm__ half* output, uint32_t input_total_length)
{
    asc_vf_call<simt_float22half2_rn>(dim3(1024), (__gm__ float2*)input, (__gm__ half2*)output, input_total_length);
}
```
